@@ -1,25 +1,12 @@
-/********************************************************************
-Copyright 2016  Eike Hein <hein.org>
+/*
+    SPDX-FileCopyrightText: 2016 Eike Hein <hein@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
+#pragma once
 
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
-
-#ifndef WAYLANDTASKSMODEL_H
-#define WAYLANDTASKSMODEL_H
+#include <memory>
 
 #include "abstractwindowtasksmodel.h"
 
@@ -29,10 +16,8 @@ namespace KWayland
 {
 namespace Client
 {
-class PlasmaWindowManagement;
 class Surface;
 }
-
 }
 
 namespace TaskManager
@@ -233,9 +218,7 @@ public:
 
 private:
     class Private;
-    QScopedPointer<Private> d;
+    std::unique_ptr<Private> d;
 };
 
 }
-
-#endif
